###############################################################################
#	Filename:	Kiska.py
#	
#	Confidential and Proprietary, Copyright 2000 by Totally Games
#	
#	Loads Kiska Lomar, Helm, and configures animations
#	
#	Created:	3/28/00 -	Erik Novales
#           Modified: 2/06/05                Blackrook32
###############################################################################

import App
import CharacterPaths
import Bridge.Characters.MediumAnimations

#kDebugObj = App.CPyDebug()

###############################################################################
#	CreateCharacter()
#
#	Create Kiska by building her character and placing her on the passed in set.
#	Create her menus as well.
#
#	Args:	pSet	- the Set in which to place ourselves
#
#	Return:	none
###############################################################################
def CreateCharacter(pSet):
#	kDebugObj.Print("Creating Kiska")

	if (pSet.GetObject("Helm") != None):
		return(App.CharacterClass_Cast(pSet.GetObject("Helm")))

	CharacterPaths.UpdatePaths()
	# Create the character
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcBodyNIFPath + "BodyFemM/BodyFemM.nif", "Bip01")
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcHeadNIFPath + "HeadKiska/kiska_head.nif", None)
	pSC4Kiska = App.CharacterClass_Create(CharacterPaths.g_pcBodyNIFPath + "BodyFemM/BodyFemM.nif", CharacterPaths.g_pcHeadNIFPath + "HeadKiska/kiska_head.nif", 1)
	pSC4Kiska.ReplaceBodyAndHead(CharacterPaths.g_pcBodyTexPath + "BodyFemS/FedFemRed_body.tga", CharacterPaths.g_pcHeadTexPath + "HeadKiska/kiska_head.tga")

	pSC4Kiska.SetCharacterName("Kiska")

	# Add the character to the set
	pSet.AddObjectToSet(pSC4Kiska, "Helm")
	pLight = pSet.GetLight("ambientlight1")
	pLight.AddIlluminatedObject(pSC4Kiska)

	# Setup the character configuration
	pSC4Kiska.SetSize(App.CharacterClass.MEDIUM)
	pSC4Kiska.SetGender(App.CharacterClass.FEMALE)
	pSC4Kiska.SetStanding(0)
	pSC4Kiska.SetRandomAnimationChance(0.65)
	pSC4Kiska.SetBlinkChance(0.1)
	pSC4Kiska.SetDatabase("data/TGL/Bridge Crew General.tgl")

	# Load Helm officer generic sounds
	LoadSounds()
	AddCommonAnimations(pSC4Kiska)

	pSC4Kiska.AddFacialImage("Blink0", CharacterPaths.g_pcHeadTexPath + "HeadKiska/Kiska_head_blink1.tga")
	pSC4Kiska.AddFacialImage("Blink1", CharacterPaths.g_pcHeadTexPath + "HeadKiska/Kiska_head_blink2.tga")
	pSC4Kiska.AddFacialImage("Blink2", CharacterPaths.g_pcHeadTexPath + "HeadKiska/Kiska_head_eyesclosed.tga")
	pSC4Kiska.SetBlinkStages(3)

	pSC4Kiska.AddFacialImage("SpeakA", CharacterPaths.g_pcHeadTexPath + "HeadKiska/Kiska_head_a.tga")
	pSC4Kiska.AddFacialImage("SpeakE", CharacterPaths.g_pcHeadTexPath + "HeadKiska/Kiska_head_e.tga")
	pSC4Kiska.AddFacialImage("SpeakU", CharacterPaths.g_pcHeadTexPath + "HeadKiska/Kiska_head_u.tga")
	pSC4Kiska.SetAnimatedSpeaking(1)

	pGame = App.Game_GetCurrentGame()
	pGame.LoadDatabaseSoundInGroup(pKiska.GetDatabase(), "KiskaNothingToAdd", "BridgeGeneric")

	pMenusDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Menus.tgl")
	pTop = App.TopWindow_GetTopWindow()
	pTacticalControlWindow = App.TacticalControlWindow_GetTacticalControlWindow()
	pSC4Kiska.SetMenu(pTacticalControlWindow.FindMenu(pMenusDatabase.GetString("Helm")))
	App.g_kLocalizationManager.Unload(pMenusDatabase)

#	kDebugObj.Print("Finished creating Kiska")
	return pSC4Kiska


###############################################################################
#	ConfigureForShip()
#
#	Configure ourselves for the particular ship object.  This involves setting
#	up range watchers that tell us how to report.
#
#	Args:	pSet	- the Set object
#			pShip	- the player's ship (ShipClass object)
#
#	Return:	none
###############################################################################
def ConfigureForShip(pSet, pShip):
	pSC4Kiska = App.CharacterClass_Cast(pSet.GetObject("Helm"))
	if (pSC4Kiska == None):
		return

	import Bridge.HelmCharacterHandlers
	Bridge.HelmCharacterHandlers.AttachMenuToHelm(pSC4Kiska)


def ConfigureForType11(pSC4Kiska):

	pSC4Kiska.ClearAnimations()

	pSC4Kiska.ClearAnimations()

	# Register animation mappings
	pSC4Kiska.AddAnimation("EBL1MToH", "Bridge.Characters.MediumAnimations.EBMoveFromL1ToH")
	pSC4Kiska.AddAnimation("EBHelmToL1", "Bridge.Characters.MediumAnimations.EBMoveFromHToL1")
	pSC4Kiska.AddAnimation("EBHelmTurnCaptain", "Bridge.Characters.MediumAnimations.EBTurnAtHTowardsCaptain")
	pSC4Kiska.AddAnimation("EBHelmBackCaptain", "Bridge.Characters.MediumAnimations.EBTurnBackAtHFromCaptain")

	pSC4Kiska.AddAnimation("EBHelmTurnC", "Bridge.Characters.MediumAnimations.EBHTalkC")
	pSC4Kiska.AddAnimation("EBHelmBackC", "Bridge.Characters.MediumAnimations.EBHTalkFinC")
	pSC4Kiska.AddAnimation("EBHelmTurnE", "Bridge.Characters.MediumAnimations.EBHTalkE")
	pSC4Kiska.AddAnimation("EBHelmBackE", "Bridge.Characters.MediumAnimations.EBHTalkFinE")
	pSC4Kiska.AddAnimation("EBHelmTurnS", "Bridge.Characters.MediumAnimations.EBHTalkS")
	pSC4Kiska.AddAnimation("EBHelmBackS", "Bridge.Characters.MediumAnimations.EBHTalkFinS")
	pSC4Kiska.AddAnimation("EBHelmTurnT", "Bridge.Characters.MediumAnimations.EBHTalkT")
	pSC4Kiska.AddAnimation("EBHelmBackT", "Bridge.Characters.MediumAnimations.EBHTalkFinT")

	pSC4Kiska.AddAnimation("EBHelmTurnX", "Bridge.Characters.MediumAnimations.EBHTalkE")
	pSC4Kiska.AddAnimation("EBHelmBackX", "Bridge.Characters.MediumAnimations.EBHTalkFinE")

	pSC4Kiska.AddAnimation("EBHelmGlanceCaptain", "Bridge.Characters.CommonAnimations.GlanceRight")
	pSC4Kiska.AddAnimation("EBHelmGlanceAwayCaptain", "Bridge.Characters.CommonAnimations.SeatedM")

	# Breathing
	pSC4Kiska.AddAnimation("EBHelmBreathe", "Bridge.Characters.CommonAnimations.SeatedM")

	# Interaction
	pSC4Kiska.AddRandomAnimation("Bridge.Characters.MediumAnimations.DBHConsoleInteraction", App.CharacterClass.SITTING_ONLY, 25, 1)

	# So the mission builders can force the call
	pSC4Kiska.AddAnimation("PushingButtons", "Bridge.Characters.MediumAnimations.DBHConsoleInteraction")

	# Hit animations
	#pSC4Kiska.AddAnimation("EBHelmHit", "Bridge.Characters.MediumAnimations.HHit")
	#pSC4Kiska.AddAnimation("EBHelmHitHard", "Bridge.Characters.MediumAnimations.HHitHard")
	pSC4Kiska.AddAnimation("EBHelmReactLeft", "Bridge.Characters.CommonAnimations.ReactLeft")
	pSC4Kiska.AddAnimation("EBHelmReactRight", "Bridge.Characters.CommonAnimations.ReactRight")

	
	AddCommonAnimations(pSC4Kiska)

	pSC4Kiska.SetStanding(0)
	pSC4Kiska.SetLocation("RunCommander")
	pSC4Kiska.SetTranslateXYZ(5.000000, 0.000000, 0.000000)
	
def AddCommonAnimations(pSC4Kiska):
	
	# Just random stuff
	pSC4Kiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadLeft")
	pSC4Kiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadRight")
	pSC4Kiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookUp")
	pSC4Kiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookDown")
	pSC4Kiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.ConsoleLookDownForeLeft")
	pSC4Kiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.ConsoleLookUpForeRight")
	pSC4Kiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookAroundConsoleDown")


###############################################################################
#	LoadSounds()
#
#	Load generic bridge sounds for this character
#
#	Args:	none
#
#	Return:	none
###############################################################################
def LoadSounds():
	pGame = App.Game_GetCurrentGame()
	pDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Crew General.tgl")

	#
	# Build a list of sound to load
	#
	lSoundList =	[	"KiskaSir1",	# Click Response
						"KiskaSir2",
						"KiskaSir3",
						"KiskaSir4",
						"KiskaSir5",
						
						"KiskaYes1",	# Order Confirmation
						"KiskaYes2",
						"KiskaYes3",
						"KiskaYes4",

						"gh075",	# Course laid in
						"gh081",	# Intercept course plotted

						"HailOpen1",
						"HailOpen2",
						"NotResponding1",
						"NotResponding2",
						"OnScreen",

						"CollisionAlert1",
						"CollisionAlert2",
						"CollisionAlert3",
						"CollisionAlert4",
						"CollisionAlert5",
						"CollisionAlert6",
						"CollisionAlert7",
						"CollisionAlert10",

						"IncomingMsg1",
						"IncomingMsg2",
						"IncomingMsg3",
						"IncomingMsg4",
						"IncomingMsg5",
						"IncomingMsg6",
					]
	#
	# Loop through that list, loading each sound in the "BridgeGeneric" group
	#
	for sLine in lSoundList:
		pGame.LoadDatabaseSoundInGroup(pDatabase, sLine, "BridgeGeneric")

	App.g_kLocalizationManager.Unload(pDatabase)
