###############################################################################
#	Filename:	Felix.py
#	
#	Confidential and Proprietary, Copyright 2000 by Totally Games
#	
#	Loads Felix Savali, tactical officer, and configures animations.
#	
#	Created:	3/28/00 -	Erik Novales
#           Modified: 2/06/05                Blackrook32
###############################################################################

import App
import CharacterPaths


###############################################################################
#	CreateCharacter()
#
#	Create Felix by building his character and placing him on the passed in set.
#	Create his menus as well.
#
#	Args:	pSet	- the Set in which to place ourselves
#
#	Return:	none
###############################################################################
def CreateCharacter(pSet):
        
	if (pSet.GetObject("Tactical") != None):
		return(App.CharacterClass_Cast(pSet.GetObject("Tactical")))

	CharacterPaths.UpdatePaths()
	
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcBodyNIFPath + "BodyMaleL/BodyMaleL.nif", "Bip01")
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcHeadNIFPath + "HeadFelix/felix_head.nif", None)
	pT9Felix = App.CharacterClass_Create(CharacterPaths.g_pcBodyNIFPath + "BodyMaleL/BodyMaleL.nif", CharacterPaths.g_pcHeadNIFPath + "HeadFelix/felix_head.nif")
	pT9Felix.ReplaceBodyAndHead(CharacterPaths.g_pcBodyTexPath + "BodyMaleM/FedGold_body.tga", CharacterPaths.g_pcHeadTexPath + "HeadFelix/felix_head.tga")

	pT9Felix.SetCharacterName("Felix")

	pSet.AddObjectToSet(pT9Felix, "Tactical")
	pLight = pSet.GetLight("ambientlight1")
	pLight.AddIlluminatedObject(pT9Felix)

	pT9Felix.SetSize(App.CharacterClass.LARGE)
	pT9Felix.SetGender(App.CharacterClass.MALE)
	pT9Felix.SetStanding(0)
	pT9Felix.SetRandomAnimationChance(0.35)
	pT9Felix.SetBlinkChance(0.1)
	pT9Felix.SetAudioMode(App.CharacterClass.CAM_EXTREMELY_VOCAL)
	pT9Felix.SetDatabase("data/TGL/Bridge Crew General.tgl")

	LoadSounds()
        
	pT9Felix.AddFacialImage("Blink0", CharacterPaths.g_pcHeadTexPath + "HeadFelix/Felix_blink1.tga")
	pT9Felix.AddFacialImage("Blink1", CharacterPaths.g_pcHeadTexPath + "HeadFelix/Felix_blink2.tga")
	pT9Felix.AddFacialImage("Blink2", CharacterPaths.g_pcHeadTexPath + "HeadFelix/Felix_eyesclosed.tga")
	pT9Felix.SetBlinkStages(3)

	pT9Felix.AddFacialImage("SpeakA", CharacterPaths.g_pcHeadTexPath + "HeadFelix/Felix_head_a.tga")
	pT9Felix.AddFacialImage("SpeakE", CharacterPaths.g_pcHeadTexPath + "HeadFelix/Felix_head_e.tga")
	pT9Felix.AddFacialImage("SpeakU", CharacterPaths.g_pcHeadTexPath + "HeadFelix/Felix_head_u.tga")
	pT9Felix.SetAnimatedSpeaking(1)

	pMenusDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Menus.tgl")
	pTop = App.TopWindow_GetTopWindow()
	pTacticalControlWindow = App.TacticalControlWindow_GetTacticalControlWindow()
	pT9Felix.SetMenu(pTacticalControlWindow.FindMenu(pMenusDatabase.GetString("Tactical")))
	App.g_kLocalizationManager.Unload(pMenusDatabase)

	pT9Felix.SetLocation("")

	return pT9Felix


def ConfigureForShip(pSet, pShip):
	pT9Felix = App.CharacterClass_Cast(pSet.GetObject("Tactical"))
	if (pT9Felix == None):
		return

	import Bridge.TacticalCharacterHandlers
	Bridge.TacticalCharacterHandlers.AttachMenuToTactical(pFelix)

def ConfigureForType11(pT9Felix):
        
	pT9Felix.ClearAnimations()

	# Register animation mappings
	pT9Felix.AddAnimation("SeatedEBTactical", "Bridge.Characters.CommonAnimations.SeatedL")
	pT9Felix.AddAnimation("EBL1LToT", "Bridge.Characters.LargeAnimations.EBMoveFromL1ToT")
	pT9Felix.AddAnimation("EBTacticalToL1", "Bridge.Characters.LargeAnimations.EBMoveFromTToL1")
	pT9Felix.AddAnimation("EBTacticalTurnCaptain", "Bridge.Characters.LargeAnimations.EBTurnAtTTowardsCaptain")
	pT9Felix.AddAnimation("EBTacticalBackCaptain", "Bridge.Characters.LargeAnimations.EBTurnBackAtTFromCaptain")

	pT9Felix.AddAnimation("EBTacticalTurnC", "Bridge.Characters.LargeAnimations.EBTTalkC")
	pT9Felix.AddAnimation("EBTacticalBackC", "Bridge.Characters.LargeAnimations.EBTTalkFinC")
	pT9Felix.AddAnimation("EBTacticalTurnE", "Bridge.Characters.LargeAnimations.EBTTalkE")
	pT9Felix.AddAnimation("EBTacticalBackE", "Bridge.Characters.LargeAnimations.EBTTalkFinE")
	pT9Felix.AddAnimation("EBTacticalTurnH", "Bridge.Characters.LargeAnimations.EBTTalkH")
	pT9Felix.AddAnimation("EBTacticalBackH", "Bridge.Characters.LargeAnimations.EBTTalkFinH")
	pT9Felix.AddAnimation("EBTacticalTurnS", "Bridge.Characters.LargeAnimations.EBTTalkS")
	pT9Felix.AddAnimation("EBTacticalBackS", "Bridge.Characters.LargeAnimations.EBTTalkFinS")

	pT9Felix.AddAnimation("EBTacticalTurnX", "Bridge.Characters.LargeAnimations.EBTTalkE")
	pT9Felix.AddAnimation("EBTacticalBackX", "Bridge.Characters.LargeAnimations.EBTTalkFinE")

	pT9Felix.AddAnimation("EBTacticalGlanceCaptain", "Bridge.Characters.CommonAnimations.GlanceLeft")
	pT9Felix.AddAnimation("EBTacticalGlanceAwayCaptain", "Bridge.Characters.CommonAnimations.SeatedL")

	# Breathing
	pT9Felix.AddAnimation("EBTacticalBreathe", "Bridge.Characters.CommonAnimations.SeatedL")
	pT9Felix.AddAnimation("EBTacticalBreatheTurned", "Bridge.Characters.CommonAnimations.BreathingTurned")

	# Interaction
	pT9Felix.AddRandomAnimation("Bridge.Characters.LargeAnimations.EBTConsoleInteraction", App.CharacterClass.SITTING_ONLY, 25, 1)

	# So the mission builders can force the call
	pT9Felix.AddAnimation("PushingButtons", "Bridge.Characters.LargeAnimations.EBTConsoleInteraction")

	# Hit animations		
	#pT9Felix.AddAnimation("EBTacticalHit", "Bridge.Characters.LargeAnimations.THit")
	#pT9Felix.AddAnimation("EBTacticalHitHard", "Bridge.Characters.LargeAnimations.THitHard")
	pT9Felix.AddAnimation("EBTacticalReactLeft", "Bridge.Characters.CommonAnimations.ReactLeft")
	pT9Felix.AddAnimation("EBTacticalReactRight", "Bridge.Characters.CommonAnimations.ReactRight")
	
	
	AddCommonAnimations(pT9Felix)
	
	pT9Felix.SetStanding(0)
	pT9Felix.SetLocation("RunCommander")
	pT9Felix.AddPositionZoom("RunCommander", 1.0, "Tactical")
	pT9Felix.SetLookAtAdj(52.9137, -368.734, 158.715797)

def AddCommonAnimations(pFelix):

	# Just random stuff
	pFelix.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadLeft")
	pFelix.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadRight")
	pFelix.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookUp")
	pFelix.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookDown")
	
def LoadSounds():
	pGame = App.Game_GetCurrentGame()
	pDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Crew General.tgl")

	for sLine in g_lsFelixLines:
		pGame.LoadDatabaseSoundInGroup(pDatabase, sLine, "BridgeGeneric")

	App.g_kLocalizationManager.Unload(pDatabase)

g_lsFelixLines = (
	"AttackStatus_EvadingTorps1",
	"AttackStatus_FallingBack1",
	"AttackStatus_LiningUpFront1",
	"AttackStatus_MovingIn1",
	"AttackStatus_RearTorpRun1",
	"AttackStatus_SweepingPhasers1",
	"BadTarget1",
	"BadTarget2",
	"Disengaging",
	"DontShootTac",
	"EvasiveManuvers", # Sumbody furgot to spel this rite.
	"FelixEnDes",
	"FelixNothingToAdd",
	"FelixNothingToAdd2",
	"FelixNothingToAdd3",
	"FelixSir1",
	"FelixSir2",
	"FelixSir3",
	"FelixSir4",
	"FelixSir5",
	"FelixYes1",
	"FelixYes2",
	"FelixYes3",
	"FelixYes4",
	"ForeShieldsOffline",
	"Incoming1",
	"Incoming2",
	"Incoming3",
	"Incoming4",
	"Incoming5",
	"Incoming6",
	"LoadingPhoton",
	"LoadingQuantum",
	"LoadingTorps",
	"NeedPower",
	"OutOfPhotons",
	"OutOfQuantums",
	"OutOfType",
	"TacticalManuver", # This wun to.
	"gt001",
	"gt002",
	"gt007",
	"gt029",
	"gt030",
	"gt037",
	"gt038",
	"gt212",
	"gt213",
	)
